#include <string.h>
#include <deque>
#include <utility> // std::pair

// You'll put together a LogEvent whenever you want to log something.
class LogEvent
{
    friend class Logger;
public:
    LogEvent() : useArea_(false), useMessage_(false), useValue_(false), useLocation_(false) {};
    void SetArea(std::string area)
    {
        area_ = area;
        useArea_ = true;
    };
    void SetEventID(std::string eventID)
    {
        eventID_ = eventID;
        useEventID_ = true;
    };
    void SetValue(float value)
    {
        value_ = value;
        useValue_ = true;
    };
    void SetLocation(Point location)
    {
        location_ = location;
        useLocation_ = true;
    };
private:
    std::string GetString(std::string userID, std::string sessionID, std::string build);

    bool useArea_;
    bool useEventID_;
    bool useValue_;
    bool useLocation_;

    std::string area_;
    std::string message_;
    float value_;
    Point location_;
};

// The main class for logging and sending events.
class Logger
{
public:
    Logger(void);
    void AddLogEvent(LogEvent ev);
    void SubmitLogEvents(void);
    void LoadHeatmap(std::string area, std::string eventID);
    bool GetHeatmap(std::string area, std::deque<std::pair<Point, int>>& points);
private:
    void SetUserID(void);
    void SetSessionID(void);
    int DataToString(char *data, size_t size, size_t nmemb, std::string * result);

    // Yes I know this is a lot of strings. DEAL.
    std::string apiVersion_;
    std::string gameKey_;
    std::string apiKey_;
    std::string gaEvents_;
    std::string userID_;
    std::string sessionID_;

    // This makes PERFECT SENSE.
    std::map<std::string, std::deque<std::pair<Point, int>>> heatmaps_;
};

// Generic Point class, for heatmaps. Just to be thorough.
class Point
{
    Point(void) : x(0.f), y(0.f), z(0.f) {};
    Point(float x_, float y_, float z_) : x(x_), y(y_), z(z_) {};
    float x;
    float y;
    float z;
};
